# OceanRobots.jl

Simulation, processing, and analysis of data generated by scientific robots in the Ocean. These include profiling floats, drifters, gliders, and moorings for examples.

## Notebooks

The suite of examples includes :

- [Buoy\_NWP\_NOAA.jl](Buoy_NWP_NOAA.html) (➭ [code link](https://raw.githubusercontent.com/JuliaOcean/OceanRobots.jl/master/examples/Buoy_NWP_NOAA.jl)) : NOAA [station](https://www.ndbc.noaa.gov/) data (a few days)
- [Buoy\_NWP\_NOAA\_monthly.jl](Buoy_NWP_NOAA_monthly.html) (➭ [code link](https://raw.githubusercontent.com/JuliaOcean/OceanRobots.jl/master/examples/Buoy_NWP_NOAA_monthly.jl)) : NOAA [station](https://www.ndbc.noaa.gov/) data (monthly means) 
- [Mooring\_WHOTS.jl](Mooring_WHOTS.html) (➭ [code link](https://raw.githubusercontent.com/JuliaOcean/OceanRobots.jl/master/examples/Mooring_WHOTS.jl)) : WHOTS [mooring](http://www.soest.hawaii.edu/whots/wh_data.html) data
- [Drifter\_GDP.jl](Drifter_GDP.html) (➭ [code link](https://raw.githubusercontent.com/JuliaOcean/OceanRobots.jl/master/examples/Drifter_GDP.jl)) : [drifter](https://www.aoml.noaa.gov/phod/gdp/hourly_data.php) time series
- [Drifter\_CloudDrift.jl](https://juliaocean.github.io/OceanRobots.jl/v0.1.10/Drifter_CloudDrift.html) (➭ [code link](https://github.com/JuliaOcean/OceanRobots.jl/blob/master/examples/Drifter_CloudDrift.jl)) : drifter statistics
- [Float\_Argo.jl](Float_Argo.html) (➭ [code link](https://raw.githubusercontent.com/JuliaOcean/OceanRobots.jl/master/examples/Float_Argo.jl)) : Argo profiling [float](https://argo.ucsd.edu) data
- [Glider\_Spray.jl](Glider_Spray.html) (➭ [code link](https://raw.githubusercontent.com/JuliaOcean/OceanRobots.jl/master/examples/Glider_Spray.jl)) : underwater [glider](http://spraydata.ucsd.edu/projects/) data.

!!! note
    The static `html` rendering of the notebooks (this website) lack the interactivity that comes from [Running The Examples](@ref) yourself.
	
!!! warning	
    This package is in early developement stage when breaking changes can be expected._
	
### Running The Examples

The examples are most easily run using [Pluto.jl](https://github.com/fonsp/Pluto.jl). To do it this way, one just needs to copy a `code link` provided above and paste this URL into the [Pluto.jl interface](https://github.com/fonsp/Pluto.jl/wiki/🔎-Basic-Commands-in-Pluto).

### Additional examples

- For Argo and state estimates, see [ArgoData.jl](https://github.com/JuliaOcean/ArgoData.jl)
- For drifter data simulations, see [IndividualDisplacements.jl](https://github.com/JuliaClimate/IndividualDisplacements.jl)

### Visual Examples

The plots below are generated by the notebook examples.

Argo Float Track            |  Argo Float Profiles 
:------------------------------:|:---------------------------------:
![](https://user-images.githubusercontent.com/20276764/166470235-467a9326-18ae-4934-a866-2da06ec9ec84.png)  |  ![](https://user-images.githubusercontent.com/20276764/166470217-f89d2374-f57e-4a28-8220-86179e6c1f86.png)
GDP Surface Drifter Data | WHOTS Mooring Data 
![](https://user-images.githubusercontent.com/20276764/149673826-a43e2a44-f4e5-437b-99cb-5e032228b3af.png) | ![](https://user-images.githubusercontent.com/20276764/149675305-82364bde-e3a9-4975-8fb2-fb67e17dacc5.png)
Spray Glider Data | NOAA Time series 
![](https://user-images.githubusercontent.com/20276764/166470390-952e89df-60ad-4a45-b015-9469c3c297de.png) | ![](https://user-images.githubusercontent.com/20276764/166470257-8a0421ff-b147-46aa-b03b-43e5f8b4d1b3.png)

## Functionalities

```@index
```

```@autodocs
Modules = [GDP, NOAA, GliderFiles, ArgoFiles, OceanSites, THREDDS]
```
